@@ -35,7 +35,6 @@
 #include "system.h"
 #include "xsystem35.h"
 #include "modules.h"
-#include "sdl_core.h"
 #include "input.h"
 #include "menu.h"
 
@@ -54,7 +53,7 @@ static void OutputMessageBox(void) { /* 0 */
 	char *title_utf8 = toUTF8(svar_get(title));
 	char *msg_utf8 = toUTF8(svar_get(msg));
 
-	sdl_showMessageBox(MESSAGEBOX_INFO, title_utf8, msg_utf8);
+	sys_show_message_box(MESSAGEBOX_INFO, title_utf8, msg_utf8);
 
 	free(title_utf8);
 	free(msg_utf8);
