@@ -17,26 +17,26 @@ static void Init() {
         
         *var = 1;
         
-        DEBUG_COMMAND_YET("eeDEMO.Init %d,%d,%d,%p:", p1, p2, p3, var);
+        TRACE_UNIMPLEMENTED("eeDEMO.Init %d,%d,%d,%p:", p1, p2, p3, var);
 }
 
 static void SetKeyCancelFlag() {
         int cancelflag = getCaliValue();
         
-        DEBUG_COMMAND_YET("eeDEMO.SetKeyCancelFlag %d:", cancelflag);
+        TRACE_UNIMPLEMENTED("eeDEMO.SetKeyCancelFlag %d:", cancelflag);
 }
 
 static void SetLoopFlag() {
         /* Loop Flag */
         int loopflag = getCaliValue(); /* 0 なら無限繰り返し */
         
-        DEBUG_COMMAND_YET("eeDEMO.SetLoopFlag %d:", loopflag);
+        TRACE_UNIMPLEMENTED("eeDEMO.SetLoopFlag %d:", loopflag);
 }
 
 static void Run() {
         int p1 = getCaliValue();
 	
-        DEBUG_COMMAND_YET("eeDEMO.Run %d:", p1);
+        TRACE_UNIMPLEMENTED("eeDEMO.Run %d:", p1);
 }
 
 static const ModuleFunc functions[] = {
