@@ -38,7 +38,7 @@
 #include "utfsjis.h"
 #include "hankaku.h"
 #include "ags.h"
-#include "sdl_core.h"
+#include "gfx.h"
 #include "ald_manager.h"
 #include "LittleEndian.h"
 #include "hacks.h"
@@ -107,7 +107,7 @@ void commands2F04() {
 
 void commands2F05() {
 	/* 現在のテキスト表示位置をスタックにプッシュする */
-	MyPoint loc;
+	SDL_Point loc;
 	msg_getMessageLocation(&loc);
 	sl_pushTextLoc(loc.x, loc.y);
 	TRACE("TPP:");
@@ -706,7 +706,7 @@ void commands2F43() {
 	int eLength = getCaliValue();
 	int eColor  = getCaliValue();
 
-	sdl_fillCircle(eX, eY, eLength, eColor);
+	gfx_fillCircle(eX, eY, eLength, eColor);
 	ags_updateArea(eX, eY, eLength, eLength);
 
 	TRACE("grDrawFillCircle %d, %d, %d, %d:", eX, eY, eLength, eColor);
@@ -781,10 +781,10 @@ void commands2F4C() {
 	int eWidth  = getCaliValue();
 	int eHeight = getCaliValue();
 
-	MyRectangle r = {eSrcX, eSrcY, eWidth, eHeight};
-	MyPoint p = {eX, eY};
+	SDL_Rect r = {eSrcX, eSrcY, eWidth, eHeight};
+	SDL_Point p = {eX, eY};
 	
-	sdl_updateArea(&r, &p);
+	gfx_updateArea(&r, &p);
 	
 	TRACE("grBlt %d, %d, %d, %d, %d, %d:",
 		      eX, eY, eSrcX, eSrcY, eWidth, eHeight);
@@ -943,7 +943,7 @@ void commands2F5A() {
 	char *t1;
 	
 	t1 = toUTF8(sText);
-	sdl_showMessageBox(MESSAGEBOX_INFO, nact->game_title_utf8, t1);
+	sys_show_message_box(MESSAGEBOX_INFO, nact->game_title_utf8, t1);
 	free(t1);
 	
 	TRACE("strMessageBox %s:", sText);
@@ -954,7 +954,7 @@ void commands2F5B() {
 	char *t1;
 	
 	t1 = toUTF8(svar_get(eNum));
-	sdl_showMessageBox(MESSAGEBOX_INFO, nact->game_title_utf8, t1);
+	sys_show_message_box(MESSAGEBOX_INFO, nact->game_title_utf8, t1);
 	free(t1);
 	
 	TRACE("strMessageBoxStr %d:", eNum);
