@@ -23,13 +23,217 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <SDL.h>
 
 #include "portab.h"
 #include "system.h"
 #include "cursor.h"
 #include "LittleEndian.h"
 #include "ald_manager.h"
-#include "sdl_core.h"
+
+#include "bitmaps/cursor_uparrow.xpm"
+
+#define CURSOR_ARROW     1
+#define CURSOR_CROSS     2
+#define CURSOR_IBEAM     3
+#define CURSOR_ICON      4
+#define CURSOR_NO        5
+#define CURSOR_SIZE      6
+#define CURSOR_SIZEALL   7
+#define CURSOR_SIZENESW  8
+#define CURSOR_SIZENS    9
+#define CURSOR_SIZENWSE 10
+#define CURSOR_SIZEWE   11
+#define CURSOR_UPARROW  12
+#define CURSOR_WAIT     13
+
+typedef struct {
+	short idReserved;  /* always set to 0 */
+	short idType;      /* always set to 1 */
+	short idCount;     /* number of cursor images,always set to 1 */
+	/* immediately followed by idCount TCursorDirEntries */
+} CursorHeader;
+
+typedef struct {
+	unsigned char  bWidth;       /* Width */
+	unsigned char  bHeight;	     /* Height */
+	unsigned char  bColorCount;
+	unsigned char  bReserved;
+	unsigned short wxHotspot;
+	unsigned short wyHotspot;
+	unsigned long  dwBytesInRes; /* total number of bytes in image */
+	unsigned long  dwImageOffset;
+} TCursorDirEntry;
+
+typedef struct {
+	long biSize;           /* sizeof(TBitmapInfoHeader) */
+	long biWidth;          /* width of bitmap */
+	long biHeight;	       /* height of bitmap, see notes */
+	short biPlanes;	       /* planes, always 1 */
+	short biBitCount;      /* number of color bits */
+	long biCompression;    /* compression used, 0 */
+	long biSizeImage;      /* size of the pixel data, see notes */
+	long biXPelsPerMeter;  /* not used, 0 */
+	long biYPelsPerMeter;  /* not used, 0 */
+	long biClrUsed;	       /* # of colors used, set to 0 */
+	long biClrImportant;   /* important colors, set to 0 */
+	short hotX;
+	short hotY;
+} TBitmapInfoHeader;
+
+/*
+   biHeight=2*TIconDirEntry.bHeight;
+   biSizeImage=ANDmask + XORmask;
+
+   XORmask=(TIconDirEntry.bWidth * TIconDirEntry.bHeight * biBitCount)/8;
+   ANDmask=(TIconDirEntry.bWidth * TIconDirEntry.bHeight)/8;
+ */
+
+typedef struct {
+	unsigned char rgbBlue;     /* blue component of color */
+	unsigned char rgbGreen;    /* green component of color */
+	unsigned char rgbRed;      /* red component of color */
+	unsigned char rgbReserved; /* reserved, 0 */
+} TRGBQuad;
+
+typedef struct {
+	TBitmapInfoHeader icHeader; /* image header info */
+	TRGBQuad *icColors;	    /* image palette */
+	int xormasklen;
+	int andmasklen;
+} CursorImage;
+
+typedef struct {
+	int cbSizeof;
+	int cFrames;
+	int cSteps;
+	int cx;
+	int cy;
+	int cBitCount;
+	int cPlanes;
+	int jiffRate;
+	int fl;
+
+	int *rate;
+	int *seq;
+} AnimationCursorHeader ;
+
+typedef struct {
+	AnimationCursorHeader *header;
+	CursorImage *images;
+} AniCursorImage;
+
+static SDL_Cursor *cursor[256];
+
+/* Stolen from the SDL mailing list */
+/* Creates a new mouse cursor from an XPM */
+
+static SDL_Cursor *init_system_cursor(const char *image[]) {
+	int i, row, col;
+	Uint8 data[4*32];
+	Uint8 mask[4*32];
+	int hot_x, hot_y;
+
+	i = -1;
+	for (row = 0; row < 32; row++) {
+		for (col = 0; col < 32; col++) {
+			if (col % 8) {
+				data[i] <<= 1;
+				mask[i] <<= 1;
+			} else {
+				i++;
+				data[i] = mask[i] = 0;
+			}
+			switch (image[4 + row][col]) {
+			case 'X':
+				data[i] |= 0x01;
+				mask[i] |= 0x01;
+				break;
+			case '.':
+				mask[i] |= 0x01;
+				break;
+			case ' ':
+				break;
+			}
+		}
+	}
+	sscanf(image[4 + row], "%d,%d", &hot_x, &hot_y);
+	return SDL_CreateCursor(data, mask, 32, 32, hot_x, hot_y);
+}
+
+void cursor_init(void) {
+	cursor[CURSOR_ARROW]    = SDL_GetDefaultCursor();
+	cursor[CURSOR_CROSS]    = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_CROSSHAIR);
+	cursor[CURSOR_IBEAM]    = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_IBEAM);
+	cursor[CURSOR_ICON]     = SDL_GetDefaultCursor();
+	cursor[CURSOR_NO]       = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_NO);
+	cursor[CURSOR_SIZE]     = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_SIZEALL);
+	cursor[CURSOR_SIZEALL]  = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_SIZEALL);
+	cursor[CURSOR_SIZENESW] = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_SIZENESW);
+	cursor[CURSOR_SIZENS]   = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_SIZENS);
+	cursor[CURSOR_SIZENWSE] = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_SIZENWSE);
+	cursor[CURSOR_SIZEWE]   = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_SIZEWE);
+	cursor[CURSOR_UPARROW]  = init_system_cursor(cursor_uparrow);
+	cursor[CURSOR_WAIT]     = SDL_CreateSystemCursor(SDL_SYSTEM_CURSOR_WAIT);
+}
+
+static bool cursor_new(uint8_t* data, int no, CursorImage *cursorImage, TCursorDirEntry *cursordirentry) {
+	int    xormasklen, andmasklen, xornum;
+	int    i, j;
+	int    h = 0;
+
+	uint8_t   *buf1, *buf2, *buf3, *buf4;
+
+	xornum = (cursordirentry->bWidth * cursordirentry->bHeight);
+	xormasklen = (xornum * cursorImage->icHeader.biBitCount) / 8;
+	NOTICE("Cursor:  xormasklen==%d,  xornum==%d", xormasklen, xornum);
+
+	andmasklen = xornum / 8;
+	cursorImage->xormasklen = xormasklen;
+	cursorImage->andmasklen = andmasklen;
+
+	buf1 = malloc(sizeof(uint8_t) * xornum);
+	buf2 = malloc(sizeof(uint8_t) * xornum);
+	buf3 = malloc(sizeof(uint8_t) * xornum);
+	buf4 = malloc(sizeof(uint8_t) * xornum);
+
+	memcpy(buf1, data, min(xormasklen, xornum));
+	data += xormasklen;
+
+	memcpy(buf2, data, min(andmasklen, xornum));
+	data += andmasklen;
+
+#define height cursordirentry->bHeight
+#define width  cursordirentry->bWidth
+
+	for (j = 0; j < height; j++) {
+		for (i = 0; i < width * cursorImage->icHeader.biBitCount /8; i++) {
+			buf3[h] = buf1[(height-j-1)*height*cursorImage->icHeader.biBitCount/8+i];
+			buf4[h] = 0xff ^ buf2[(height-j-1)*height*cursorImage->icHeader.biBitCount/8+i];
+			h++;
+		}
+	}
+
+	if (cursor[no])
+		SDL_FreeCursor(cursor[no]);
+	cursor[no] = SDL_CreateCursor(buf3, buf4, 32, 32, cursordirentry->wxHotspot, cursordirentry->wyHotspot);
+
+	free(buf1);
+	free(buf2);
+	free(buf3);
+	free(buf4);
+
+#undef height
+#undef width
+
+	return true;
+}
+
+void cursor_set_type(int type) {
+	if (cursor[type] != NULL) {
+		SDL_SetCursor(cursor[type]);
+	}
+}
 
 static CursorHeader    cursorHeader;
 static TCursorDirEntry cursordirentry;
@@ -293,7 +497,7 @@ static bool cursor_load_mono(uint8_t *d, int no) {
 	pos += p1;
 	
 	/* read pixedl data */
-	if (!sdl_cursorNew(d + pos, no, &cursorImage, &cursordirentry)) {
+	if (!cursor_new(d + pos, no, &cursorImage, &cursordirentry)) {
 		WARNING("unable to read pixel data");
 		return false;
 	}
