@@ -28,6 +28,15 @@
 #include <stdint.h>
 #include "config.h"
 
+#ifdef _WIN32
+# ifdef min
+#  undef min
+# endif
+# ifdef max
+#  undef max
+# endif
+# define NOMINMAX
+#endif
 #define min(x,y) ((x) < (y) ? (x) : (y))
 #define max(x,y) ((x) > (y) ? (x) : (y))
 
