@@ -113,11 +113,7 @@ typedef struct {
 	emscripten_align1_int rsv2;
 } asd_varPageHdr;
 
-#ifdef __EMSCRIPTEN__
-static enum save_format save_format = SAVEFMT_XSYS35;
-#else
 static enum save_format save_format = SAVEFMT_SYS38;
-#endif
 
 #ifdef __EMSCRIPTEN__
 EM_JS(void, scheduleSync, (), {
@@ -214,7 +210,7 @@ static int loadVarPage(char *buf) {
 
 	int cnt = head->size / sizeof(uint16_t);
 	if (varPage[page].size < cnt || varPage[page].value == NULL) {
-		if (!v_allocatePage(page, cnt, TRUE)) {
+		if (!v_allocatePage(page, cnt, true)) {
 			WARNING("Array allocation failed: page=%d size=%d", page, cnt);
 			return SAVE_LOADERR;
 		}
@@ -280,6 +276,7 @@ static void writeAsdFooter(enum save_format format, FILE *fp) {
 あとで free(*buf)するのを忘れないように
 */
 static void* loadGameData(int no, int *status, int *size) {
+	void *buf = NULL;
 	FILE *fp = fopen(nact->files.save_fname[no], "rb");
 	if (!fp)
 		goto errexit;
@@ -288,12 +285,13 @@ static void* loadGameData(int no, int *status, int *size) {
 	if (filesize == 0)
 		goto errexit;
 
-	char *buf = (char *)malloc(filesize);
+	buf = malloc(filesize);
 	if (buf == NULL)
 		goto errexit;
 
 	fseek(fp, 0L, SEEK_SET);
-	fread(buf, filesize, 1, fp);
+	if (fread(buf, filesize, 1, fp) != 1)
+		goto errexit;
 	fclose(fp);
 
 	*size = (int)filesize;
@@ -301,6 +299,8 @@ static void* loadGameData(int no, int *status, int *size) {
 	return buf;
 
  errexit:
+	if (buf != NULL)
+		free(buf);
 	if (fp != NULL)
 		fclose(fp);
 	*status = SAVE_LOADERR;
@@ -324,7 +324,7 @@ static int saveGameData(int no, char *buf, int size) {
 	return status;
 }
 
-int save_setFormat(const char *format_name) {
+bool save_setFormat(const char *format_name) {
 	if (!strcmp(format_name, "xsystem35"))
 		save_format = SAVEFMT_XSYS35;
 	else if (!strcmp(format_name, "system36"))
@@ -335,9 +335,9 @@ int save_setFormat(const char *format_name) {
 		save_format = SAVEFMT_SYS38;
 	else {
 		WARNING("unknown save format %s", format_name);
-		return NG;
+		return false;
 	}
-	return OK;
+	return true;
 }
 
 /* savefile を参照 */
@@ -601,7 +601,7 @@ int save_loadAll(int no) {
 		nact->sel.wininfo[j].y      = save_base->selWinInfo[i].y;
 		nact->sel.wininfo[j].width  = save_base->selWinInfo[i].width;
 		nact->sel.wininfo[j].height = save_base->selWinInfo[i].height;
-		// nact->sel.wininfo[i].save   = TRUE;
+		// nact->sel.wininfo[i].save   = true;
 	}
 	for (int i = 0; i < MSGWINMAX; i++) {
 		int j = format == SAVEFMT_XSYS35
@@ -612,7 +612,7 @@ int save_loadAll(int no) {
 		nact->msg.wininfo[j].width  = save_base->msgWinInfo[i].width;
 		nact->msg.wininfo[j].height = save_base->msgWinInfo[i].height;
 		// nact->msg.wininfo[i].savedImage = NULL;
-		// nact->msg.wininfo[i].save   = FALSE;
+		// nact->msg.wininfo[i].save   = false;
 	}
 	/* スタックのロード */
 	loadStack(format, saveTop + save_base->stackinfo);
